Coverage for src/artemis_sg/_version.py: 0%

1# file generated by setuptools_scm

2# don't change, don't track in version control

3 TYPE_CHECKING = False

4 if TYPE_CHECKING:

5 from typing import Tuple, Union

6 VERSION_TUPLE = Tuple[Union[int, str], ...]

7 else:

8 VERSION_TUPLE = object

9

10 version: str

11 __version__: str

12 __version_tuple__: VERSION_TUPLE

13 version_tuple: VERSION_TUPLE

14

15 __version__ = version = '0.5.3.dev4'

16 __version_tuple__ = version_tuple = (0, 5, 3, 'dev4')